@@ -46,6 +46,12 @@ with Python 2.5, and the setup script should install it automatically for you
 if you are using Python 2.4. However, if you get some error messages, you might
 have to install it manually (at least one user reported he had to).
 
+Unstable (development) version
+------------------------------
+
+Just run ``hg clone http://dev.pitrou.net:8000/ hgsvn`` and you'll get the
+contents of the development repository.
+
 --------
 Features
 --------
@@ -138,6 +144,29 @@ changes to SVN automatically.
 History
 -------
 
+hgsvn 0.1.4
+-----------
+
+Improvements:
+
+* Be able to pull dead (removed) SVN branches by introducing a -p (--svn-peg)
+  option to specify the SVN "peg revision". The option must be used with both
+  hgimportsvn and hgpullsvn. Patch by Cameron Hutchison.
+
+Bug fixes:
+
+* Allow copying directories with non-ASCII names (reported by Andre Klitzing).
+* Make rmtree reliable under Windows. Thanks to Mark (mwatts42) for finding
+  both the bug and the solution.
+* Fix a problem where there is a symbolic link in the SVN repository that
+  points to a directory. Patch by Cameron Hutchison.
+* ``svn log`` can output invalid XML when a commit message contains control
+  characters. Reported by Tim Wegener.
+
+Other:
+
+* License upgraded to GNU GPL v3 (or later).
+
 hgsvn 0.1.3
 -----------
 
@@ -205,8 +234,8 @@ Initial release.
 __all__ = []
 
 __author__ = 'Antoine Pitrou'
-__license__ = 'GNU General Public License (version 2 or later)'
-__versioninfo__ = (0, 1, 3)
+__license__ = 'GNU General Public License (version 3 or later)'
+__versioninfo__ = (0, 1, 4)
 
 base_version = '.'.join(map(str, __versioninfo__))
 full_version = base_version
