@@ -6,6 +6,8 @@ import locale
 from datetime import datetime
 import time
 from subprocess import Popen, PIPE, STDOUT
+import shutil
+import stat
 
 try:
     import commands
@@ -37,7 +39,7 @@ if os.name == "nt":
                 fname = os.path.join(directory, base + e)
                 if os.path.exists(fname):
                     return fname
-        return None
+        return name
 else:
     def find_program(name):
         """
@@ -47,6 +49,28 @@ else:
         return name
 
 
+def _rmtree_error_handler(func, path, exc_info):
+    """
+    Error handler for rmtree. Helps removing the read-only protection under
+    Windows (and others?).
+    Adapted from http://www.proaxis.com/~darkwing/hot-backup.py
+    and http://patchwork.ozlabs.org/bazaar-ng/patch?id=4243
+    """
+    if func in (os.remove, os.rmdir) and os.path.exists(path):
+        # Change from read-only to writeable
+        os.chmod(path, os.stat(path).st_mode | stat.S_IWRITE)
+        func(path)
+    else:
+        # something else must be wrong...
+        raise
+
+def rmtree(path):
+    """
+    Wrapper around shutil.rmtree(), to provide more error-resistent behaviour.
+    """
+    return shutil.rmtree(path, False, _rmtree_error_handler)
+
+
 locale_encoding = locale.getpreferredencoding()
 
 def shell_quote(s):
@@ -134,21 +158,29 @@ def run_shell_command(cmd, args=None, bulk_args=None, encoding=None):
 
 def run_hg(args=None, bulk_args=None):
     """
-    Run a Mercurial command.
+    Run a Mercurial command, returns the (unicode) output.
     """
     default_args = ["--encoding", "utf-8"]
-    return run_command("hg", args=default_args + (args or []),
+    output = run_command("hg", args=default_args + (args or []),
         bulk_args=bulk_args, encoding="utf-8")
+    return output.decode('utf-8')
 
 def run_svn(args=None, bulk_args=None, fail_if_stderr=False):
     """
-    Run an SVN command.
+    Run an SVN command, returns the (bytes) output.
     """
     return run_command("svn",
         args=args, bulk_args=bulk_args, fail_if_stderr=fail_if_stderr)
 
 def skip_dirs(paths, basedir="."):
-    return [p for p in paths if not os.path.isdir(os.path.join(basedir, p))]
+    """
+    Skip all directories from path list, including symbolic links to real dirs.
+    """
+    # NOTE: both tests are necessary (Cameron Hutchison's patch for symbolic
+    # links to directories)
+    return [p for p in paths
+        if not os.path.isdir(os.path.join(basedir, p))
+        or os.path.islink(os.path.join(basedir, p))]
 
 
 def hg_commit_from_svn_log_entry(entry, files=None):
@@ -175,7 +207,8 @@ def hg_tag_svn_rev(rev_number):
 
 def get_svn_rev_from_hg():
     """
-    Get the current SVN revision as reflected by the hg working copy.
+    Get the current SVN revision as reflected by the hg working copy,
+    or None if no match found.
     """
     tags = run_hg(['parents', '--template', '{tags}']).strip().split()
     for tag in tags:
