@@ -10,7 +10,7 @@ SVN URL (for example 'trunk').
 """
 
 from hgsvn.common import (
-    run_hg, skip_dirs,
+    run_hg, skip_dirs, rmtree,
     hg_commit_from_svn_log_entry, hg_exclude_options,
 )
 from hgsvn.svnclient import (
@@ -21,7 +21,6 @@ from hgsvn.run.common import run_parser, display_parser_error
 
 import sys
 import os
-import shutil
 import tempfile
 import urllib # for unquoting URLs
 from itertools import chain
@@ -32,10 +31,12 @@ from optparse import OptionParser
 
 
 def main():
-    usage = "usage: %prog [-r SVN rev] <SVN URL> [local checkout]"
+    usage = "usage: %prog [-r SVN rev] [-p SVN peg rev] <SVN URL> [local checkout]"
     parser = OptionParser(usage)
     parser.add_option("-r", "--svn-rev", type="int", dest="svn_rev",
         help="SVN revision to checkout from")
+    parser.add_option("-p", "--svn-peg", type="int", dest="svn_peg",
+        help="SVN peg revision to locate checkout URL")
     #parser.add_option("-w", "--svn-wc", dest="svn_wc", default="_svn_wc",
         #help="location of SVN working copy (default: ./_svn_wc)")
     (options, args) = run_parser(parser, __doc__)
@@ -44,6 +45,8 @@ def main():
 
     svn_url = args.pop(0).rstrip("/")
     local_repo = args and args.pop(0) or None
+    if options.svn_peg:
+       svn_url += "@" + str(options.svn_peg)
 
     # Get SVN info
     svn_info = get_svn_info(svn_url, options.svn_rev)
@@ -57,6 +60,8 @@ def main():
     # e.g. 'xmpp-subprotocols-2178-2'
     svn_branch = svn_url.split("/")[-1]
     svn_greatest_rev = svn_info['last_changed_rev']
+    if options.svn_peg:
+       svn_url += "@" + str(options.svn_peg)
 
     if not local_repo:
         local_repo = svn_branch
@@ -168,7 +173,7 @@ def main():
             os.rename(os.path.join(checkout_dir, d, ".svn"), os.path.join(d, ".svn"))
 
     finally:
-        shutil.rmtree(checkout_dir)
+        rmtree(checkout_dir)
         pass
 
     print "Finished! You can pull all SVN history with 'hgpullsvn'."
