@@ -161,8 +161,10 @@ def pull_svn_rev(log_entry, current_rev, svn_wc, wc_url, wc_base):
 
 
 def main():
-    usage = "usage: %prog [--help]"
+    usage = "usage: %prog [-p SVN peg rev] [--help]"
     parser = OptionParser(usage)
+    parser.add_option("-p", "--svn-peg", type="int", dest="svn_peg",
+       help="SVN peg revision to locate checkout URL")
     (options, args) = run_parser(parser, __doc__)
     if args:
         display_parser_error(parser, "incorrect number of arguments")
@@ -173,6 +175,10 @@ def main():
         #raise RuntimeError("%s doesn't exist, please provide the path to a proper SVN working copy" % svn_wc)
     #svn_wc_is_separate = os.path.abspath(svn_wc) != os.path.abspath(".")
 
+    svn_peg_wc = svn_wc
+    if options.svn_peg:
+       svn_peg_wc += "@" + str(options.svn_peg)
+
     # Get SVN info
     svn_info = get_svn_info('.')
     current_rev = svn_info['revision']
@@ -186,6 +192,8 @@ def main():
     wc_base = wc_url[len(repos_url):]
     # e.g. 'xmpp-subprotocols-2178-2'
     svn_branch = wc_url.split("/")[-1]
+    if options.svn_peg:
+       wc_url += "@" + str(options.svn_peg)
 
     # Get remove SVN info
     svn_greatest_rev = get_svn_info(wc_url)['last_changed_rev']
@@ -223,7 +231,7 @@ def main():
         next_rev = hgsvn_rev + 1
 
     # Load SVN log starting from current rev
-    it_log_entries = iter_svn_log_entries(svn_wc, next_rev, svn_greatest_rev)
+    it_log_entries = iter_svn_log_entries(svn_peg_wc, next_rev, svn_greatest_rev)
 
     try:
         try:
