@@ -24,6 +24,19 @@ svn_info_args = ['info', '--xml']
 svn_checkout_args = ['checkout', '-q']
 svn_status_args = ['status', '--xml', '-v', '--ignore-externals']
 
+_identity_table = "".join(map(chr, range(256)))
+_forbidden_xml_chars = "".join(
+    set(map(chr, range(32))) - set('\x09\x0A\x0D')
+)
+
+
+def strip_forbidden_xml_chars(xml_string):
+    """
+    Given an XML string, strips forbidden characters as per the XML spec.
+    (these are all control characters except 0x9, 0xA and 0xD).
+    """
+    return xml_string.translate(_identity_table, _forbidden_xml_chars)
+
 
 def svn_date_to_timestamp(svn_date):
     """
@@ -43,6 +56,7 @@ def parse_svn_info_xml(xml_string):
     as a dict.
     """
     d = {}
+    xml_string = strip_forbidden_xml_chars(xml_string)
     tree = ET.fromstring(xml_string)
     entry = tree.find('.//entry')
     d['url'] = entry.find('url').text
@@ -57,6 +71,7 @@ def parse_svn_log_xml(xml_string):
     as a list of dicts (one per log changeset).
     """
     l = []
+    xml_string = strip_forbidden_xml_chars(xml_string)
     tree = ET.fromstring(xml_string)
     for entry in tree.findall('logentry'):
         d = {}
@@ -87,6 +102,7 @@ def parse_svn_status_xml(xml_string, base_dir=None):
     as a list of dicts (one per status entry).
     """
     l = []
+    xml_string = strip_forbidden_xml_chars(xml_string)
     tree = ET.fromstring(xml_string)
     for entry in tree.findall('.//entry'):
         d = {}
