@@ -11,7 +11,14 @@ def eq_utc_timestamp(timestamp, time_tuple):
 
 
 class TestSVNDate(object):
+    """
+    Tests for SVN date handling.
+    """
+
     def test_parse(self):
+        """
+        Parsing SVN dates.
+        """
         svn_date = "2007-05-01T18:33:32.749605Z"
         timestamp = svnclient.svn_date_to_timestamp(svn_date)
         eq_(timestamp, 1178044412)
@@ -38,7 +45,14 @@ svn_info_xml = """<?xml version="1.0"?>
 </info>"""
 
 class TestSVNInfo(object):
+    """
+    Tests for handling SVN wc/repo information.
+    """
+
     def test_parse(self):
+        """
+        Parsing the output of 'svn info --xml'.
+        """
         d = svnclient.parse_svn_info_xml(svn_info_xml)
         eq_(d['url'], 'svn://svn.twistedmatrix.com/svn/Twisted/trunk')
         eq_(d['repos_url'], 'svn://svn.twistedmatrix.com/svn/Twisted')
@@ -93,9 +107,21 @@ svn_log_xml_with_empty_msg = """<?xml version="1.0"?>
 </logentry>
 </log>"""
 
+svn_log_xml_with_invalid_chars = ('<?xml version="1.0"?>'
+    + '\n<log>\n<logentry\n   revision="1722">\n<author>synic</author>\n'
+    + '<date>2006-11-08T19:56:30.120180Z</date>\n'
+    + '<msg>fixed some plugin bugs===+=\x1f\x1f\x1f---\n</msg>\n</logentry>\n</log>\n')
+
 
 class TestSVNLog(object):
+    """
+    Tests for handling SVN logs.
+    """
+
     def test_parse(self):
+        """
+        Parsing an SVN log in XML format.
+        """
         entries = svnclient.parse_svn_log_xml(svn_log_xml)
         eq_(len(entries), 2)
         e = entries[0]
@@ -126,11 +152,24 @@ class TestSVNLog(object):
         eq_(len(e['changed_paths']), 1)
 
     def test_parse_with_empty_msg(self):
+        """
+        Parsing an SVN log entry with an empty commit message.
+        """
         entries = svnclient.parse_svn_log_xml(svn_log_xml_with_empty_msg)
         eq_(len(entries), 1)
         e = entries[0]
         eq_(e['message'], "")
 
+    def test_parse_with_invalid_xml(self):
+        """
+        Parsing an SVN log entry with invalid XML characters.
+        """
+        entries = svnclient.parse_svn_log_xml(svn_log_xml_with_invalid_chars)
+        eq_(len(entries), 1)
+        msg = entries[0]['message']
+        assert msg.startswith('fixed some plugin bugs===+=')
+        assert msg.strip().endswith('---')
+
 
 svn_status_xml = """<?xml version="1.0"?>
 <status>
@@ -191,7 +230,14 @@ svn_status_xml_with_base_dir = """<?xml version="1.0"?>
 </status>"""
 
 class TestSVNStatus(object):
+    """
+    Tests for handling status of an SVN working copy.
+    """
+
     def test_parse(self):
+        """
+        Parsing the output of 'svn st --xml'.
+        """
         entries = svnclient.parse_svn_status_xml(svn_status_xml)
         eq_(len(entries), 4)
         e = entries[0]
@@ -208,6 +254,9 @@ class TestSVNStatus(object):
         eq_(e['type'], 'normal')
 
     def test_parse_with_base_dir(self):
+        """
+        Parsing the output of 'svn st --xml' with an explicit base dir.
+        """
         entries = svnclient.parse_svn_status_xml(
             svn_status_xml_with_base_dir, '/home/antoine/hgsvn')
         eq_(len(entries), 1)
